@@ -76,6 +76,10 @@ class PythonBuildTask(TaskExtensionPoint):
         env = dict(env)
         env['PYTHONPATH'] = str(prefix_override) + os.pathsep + \
             python_lib + os.pathsep + env.get('PYTHONPATH', '')
+        # coverage capture interferes with sitecustomize
+        # See also: https://docs.python.org/3/library/site.html#module-site
+        # See also: colcon/colcon-core#579
+        env.pop('COV_CORE_SOURCE', None)
 
         # determine if setuptools specific commands are available
         available_commands = await self._get_available_commands(
@@ -198,6 +202,8 @@ class PythonBuildTask(TaskExtensionPoint):
             ]
             completed = await run(
                 self.context, cmd, cwd=args.build_base, env=env)
+            if not completed.returncode:
+                os.remove(setup_py_build_space)
             return completed.returncode
 
     def _undo_install(self, pkg, args, setup_py_data, python_lib):
